@@ -2,9 +2,15 @@
 
 from typing import Callable, List
 from gaia_sdk.api.VariableRegistry import VariableRegistry
+from gaia_sdk.graphql.request.enumeration.Order import Order
+from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
 
 
 class BehaviourExecution(list):
+    """
+    Represents behaviour execution information
+    """
 
     def process_instance_id(self):
         self.append(lambda x: "processInstanceId")
