@@ -3,11 +3,14 @@ from gaia_sdk.graphql.request.type.Intent import Intent
 
 from typing import Callable, List
 from gaia_sdk.api.VariableRegistry import VariableRegistry
+from gaia_sdk.graphql.request.enumeration.Order import Order
+from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
 
 
 class CreatedIntentImpulse(list):
     """
-    Impulse which indicates the resulf of a create intent impulse
+    Impulse which indicates the result of a create intent impulse
     """
 
     def id(self):
