@@ -4,6 +4,9 @@ from gaia_sdk.graphql.request.input.StreamImpulse import StreamImpulse
 
 from typing import Callable, List
 from gaia_sdk.api.VariableRegistry import VariableRegistry
+from gaia_sdk.graphql.request.enumeration.Order import Order
+from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
 
 
 class Practice(list):
@@ -22,7 +25,7 @@ class Practice(list):
             name1 = registry.register("impulse", impulse)
             entity = StreamingImpulse()
             config(entity)
-            return f'prepare(impulse:${name1})' + '{' + entity.render(registry) + '}'
+            return f'prepare(impulse:{name1})' + '{' + entity.render(registry) + '}'
         self.append(callback)
 
     def render(self, registry: VariableRegistry):
